@@ -1420,15 +1420,8 @@ def default_dx(prod_name=None):
     '''
     dfdx = pd.read_csv(datafiles.dx) # Read in dataframe with parameters
     dxprods = dict(
-        # Default primary screening diagnostics
-        via             = dx(dfdx[dfdx.name == 'via'],              hierarchy=['positive', 'inadequate', 'negative']),
-        hpv             = dx(dfdx[dfdx.name == 'hpv'],              hierarchy=['positive', 'inadequate', 'negative']),
-        hpv1618         = dx(dfdx[dfdx.name == 'hpv1618'],          hierarchy=['positive', 'inadequate', 'negative']),
-        # Diagnostics used for confimatory testing
-        via_triage      = dx(dfdx[dfdx.name == 'via_triage'],       hierarchy=['positive', 'inadequate', 'negative']),
         # Diagnostics used to determine of subsequent care pathways
         txvx_assigner   = dx(dfdx[dfdx.name == 'txvx_assigner'],    hierarchy=['triage', 'txvx', 'none']),
-        tx_assigner     = dx(dfdx[dfdx.name == 'tx_assigner'],      hierarchy=['radiation', 'excision', 'ablation', 'none']),
     )
     if prod_name is not None:   return dxprods[prod_name]
     else:                       return dxprods
