@@ -39,10 +39,14 @@ def make_pars(**kwargs):
     pars['location']        = None      # What location to load data from -- default Seattle
     pars['lx']              = None      # Proportion of people alive at the beginning of age interval x
     pars['birth_rates']     = None      # Birth rates, loaded below
+    pars['death_rates']     = None      # Death rates, loaded below
+    pars['rel_birth']       = 1.0       # Birth rate scale factor
+    pars['rel_death']       = 1.0       # Death rate scale factor
 
     # Initialization parameters
-    pars['init_hpv_prev']   = hpd.default_init_prev # Initial prevalence
+    pars['init_hpv_prev'] = sc.dcp(hpd.default_init_prev) # Initial prevalence
     pars['init_hpv_dist'] = None  # Initial type distribution
+    pars['rel_init_prev'] = 1.0 # Initial prevalence scale factor
 
     # Simulation parameters
     pars['start']           = 2015.         # Start of the simulation
@@ -75,18 +79,20 @@ def make_pars(**kwargs):
     pars['transm2f']        = 3.69  # Relative transmissibility of insertive partners in penile-vaginal intercourse; based on https://doi.org/10.1038/srep10986: "For vaccination types, the risk of male-to-female transmission was higher than that of female-to-male transmission"
 
     # Parameters for disease progression
-    pars['clinical_cutoffs']    = {'cin1': 0.33, 'cin2':0.67, 'cin3':0.99} # Parameters the control the clinical cliassification of dysplasia
+    pars['clinical_cutoffs']    = {'cin1': 0.33, 'cin2':0.67} # Parameters the control the clinical cliassification of dysplasia
     pars['hpv_control_prob']    = 0.44 # Probability that HPV is controlled latently vs. cleared
     pars['hpv_reactivation']    = 0.025 # Placeholder
     pars['dur_cancer']          = dict(dist='lognormal', par1=12.0, par2=3.0)  # Duration of untreated invasive cerival cancer before death (years)
 
     # Parameters used to calculate immunity
-    pars['imm_init']        = dict(dist='beta', par1=5, par2=3)  # beta distribution for initial level of immunity following infection clearance
+    pars['imm_init']        = dict(dist='beta_mean', par1=0.625, par2=0.025)  # beta distribution for initial level of immunity following infection clearance. Parameters are mean and variance
     pars['imm_decay']       = dict(form=None)  # decay rate, with half life in years
     pars['imm_kin']         = None  # Constructed during sim initialization using the nab_decay parameters
     pars['imm_boost']       = []  # Multiplicative factor applied to a person's immunity levels if they get reinfected. No data on this, assumption.
     pars['immunity']        = None  # Matrix of immunity and cross-immunity factors, set by init_immunity() in immunity.py
     pars['immunity_map']    = None  # dictionary mapping the index of immune source to the type of immunity (vaccine vs natural)
+    pars['cross_imm_med']   = 0.3
+    pars['cross_imm_high']  = 0.5
 
     # all genotype properties get populated by user in init_genotypes()
     pars['genotypes']       = []  # Genotypes of the virus; populated by the user below
@@ -354,6 +360,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv16.prog_rate    = 0.5 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv16.prog_rate_sd = 0.05 # Standard deviation of the progression rate
     pars.hpv16.rel_beta     = 1  # Baseline relative transmissibility, other genotypes are relative to this
+    pars.hpv16.cancer_prob  = 0.25 # Share of CIN3s that will go on to cancer
     pars.hpv16.imm_boost    = 1.0 # TODO: look for data
     pars.hpv16.sero_prob    = 0.65 # https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -364,6 +371,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv18.prog_rate    = 0.5 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv18.prog_rate_sd = 0.05 # Standard deviation of the progression rate
     pars.hpv18.rel_beta     = 0.72  # Relative transmissibility, current estimate from Harvard model calibration of m2f tx
+    pars.hpv18.cancer_prob  = 0.15  # Share of CIN3s that will go on to cancer
     pars.hpv18.imm_boost    = 1.0 # TODO: look for data
     pars.hpv18.sero_prob    = 0.6 # https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -374,6 +382,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv31.prog_rate    = 0.5 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv31.prog_rate_sd = 0.05 # Standard deviation of the progression rate
     pars.hpv31.rel_beta     = 0.94 # Relative transmissibility, current estimate from Harvard model calibration of m2f tx
+    pars.hpv31.cancer_prob  = 0.05  # Share of CIN3s that will go on to cancer
     pars.hpv31.imm_boost    = 1.0 # TODO: look for data
     pars.hpv31.sero_prob    = 0.53 # https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -384,6 +393,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv33.prog_rate    = 0.5 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv33.prog_rate_sd = 0.05 # Standard deviation of the progression rate
     pars.hpv33.rel_beta     = 0.26 # Relative transmissibility, current estimate from Harvard model calibration of m2f tx
+    pars.hpv33.cancer_prob  = 0.05  # Share of CIN3s that will go on to cancer
     pars.hpv33.imm_boost    = 1.0 # TODO: look for data
     pars.hpv33.sero_prob    = 0.6  # https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -394,6 +404,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv35.prog_rate    = 0.5 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv35.prog_rate_sd = 0.05 # Standard deviation of the progression rate
     pars.hpv35.rel_beta     = 0.5 # Relative transmissibility, current estimate from Harvard model calibration of m2f tx
+    pars.hpv35.cancer_prob  = 0.05  # Share of CIN3s that will go on to cancer
     pars.hpv35.imm_boost    = 1.0 # TODO: look for data
     pars.hpv35.sero_prob    = 0.6  # Assumption, not provided in https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -404,6 +415,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv45.prog_rate    = 0.5 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv45.prog_rate_sd = 0.05 # Standard deviation of the progression rate
     pars.hpv45.rel_beta     = 0.77 # Relative transmissibility, current estimate from Harvard model calibration of m2f tx
+    pars.hpv45.cancer_prob  = 0.15  # Share of CIN3s that will go on to cancer
     pars.hpv45.imm_boost    = 1.0 # TODO: look for data
     pars.hpv45.sero_prob    = 0.25  # https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -414,6 +426,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv51.prog_rate    = 0.5 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv51.prog_rate_sd = 0.05 # Standard deviation of the progression rate
     pars.hpv51.rel_beta     = 0.5 # Relative transmissibility, current estimate from Harvard model calibration of m2f tx
+    pars.hpv51.cancer_prob  = 0.05  # Share of CIN3s that will go on to cancer
     pars.hpv51.imm_boost    = 1.0 # TODO: look for data
     pars.hpv51.sero_prob    = 0.6  # Assumption, not provided in https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -424,6 +437,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv52.prog_rate    = 0.5 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv52.prog_rate_sd = 0.05 # Standard deviation of the progression rate
     pars.hpv52.rel_beta     = 0.623 # Relative transmissibility, current estimate from Harvard model calibration of m2f tx
+    pars.hpv52.cancer_prob  = 0.05  # Share of CIN3s that will go on to cancer
     pars.hpv52.imm_boost    = 1.0 # TODO: look for data
     pars.hpv52.sero_prob    = 0.5  # https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -434,6 +448,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv56.prog_rate    = 0.5 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv56.prog_rate_sd = 0.05 # Standard deviation of the progression rate
     pars.hpv56.rel_beta     = 0.6 # Relative transmissibility, current estimate from Harvard model calibration of m2f tx
+    pars.hpv56.cancer_prob  = 0.15  # Share of CIN3s that will go on to cancer
     pars.hpv56.imm_boost    = 1.0 # TODO: look for data
     pars.hpv56.sero_prob    = 0.6  # Assumption, not provided in https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -444,6 +459,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv58.prog_rate    = 0.5 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv58.prog_rate_sd = 0.05 # Standard deviation of the progression rate
     pars.hpv58.rel_beta     = 0.6 # Relative transmissibility, current estimate from Harvard model calibration of m2f tx
+    pars.hpv58.cancer_prob  = 0.15  # Share of CIN3s that will go on to cancer
     pars.hpv58.imm_boost    = 1.0 # TODO: look for data
     pars.hpv58.sero_prob    = 0.65  # Assumption, not provided in https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -454,6 +470,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv6.prog_rate     = 0.05 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv6.prog_rate_sd  = 0.005 # Standard deviation of the progression rate
     pars.hpv6.rel_beta      = 0.8 # Relative transmissibility, generally calibrated to match available type distributions
+    pars.hpv6.cancer_prob   = 0.0 # Share of CIN3s that will go on to cancer
     pars.hpv6.imm_boost     = 1.0 # TODO: look for data
     pars.hpv6.sero_prob     = 0.6  # Assumption, not provided in https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -464,6 +481,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hpv11.prog_rate    = 0.05 # Rate of progression of dysplasia once it is established. This parameter is used as the growth rate within a logistic function that maps durations to progression probabilities
     pars.hpv11.prog_rate_sd = 0.005 # Standard deviation of the progression rate
     pars.hpv11.rel_beta     = 0.5 # Relative transmissibility, generally calibrated to match available type distributions
+    pars.hpv11.cancer_prob  = 0.0  # Share of CIN3s that will go on to cancer
     pars.hpv11.imm_boost    = 1.0 # TODO: look for data
     pars.hpv11.sero_prob    = 0.6  # Assumption, not provided in https://www.sciencedirect.com/science/article/pii/S2666679022000027#fig1
 
@@ -474,6 +492,7 @@ def get_genotype_pars(default=False, genotype=None):
     pars.hrhpv.prog_rate    = 0.5 # same value as for all oncogenic types
     pars.hrhpv.prog_rate_sd = 0.05 # same value as for all oncogenic types
     pars.hrhpv.rel_beta     = 0.94 # placeholder, currently assumed to be the same as for 31
+    pars.hrhpv.cancer_prob  = 0.25  # Share of CIN3s that will go on to cancer
     pars.hrhpv.imm_boost    = 1.0 # placeholder, currently assumed to be the same as for 31
     pars.hrhpv.sero_prob    = 0.5 # placeholder, currently assumed to be the same as for 31
 
@@ -484,254 +503,253 @@ def get_genotype_pars(default=False, genotype=None):
     pars.lrhpv.prog_rate    = 0.05 # placeholder, currently assumed to be the same as for 6
     pars.lrhpv.prog_rate_sd = 0.005 # placeholder, currently assumed to be the same as for 6
     pars.lrhpv.rel_beta     = 0.5 # placeholder, currently assumed to be the same as for 6
+    pars.lrhpv.cancer_prob  = 0.0  # Share of CIN3s that will go on to cancer
     pars.lrhpv.imm_boost    = 1.0 # placeholder, currently assumed to be the same as for 6
     pars.lrhpv.sero_prob    = 0.6  # placeholder, currently assumed to be the same as for 6
 
     return _get_from_pars(pars, default, key=genotype, defaultkey='hpv16')
 
 
-def get_cross_immunity(default=False, genotype=None):
+def get_cross_immunity(cross_imm_med=None, cross_imm_high=None, default=False, genotype=None):
     '''
     Get the cross immunity between each genotype in a sim
     '''
-    med_imm = 0.3
-    high_imm = 0.5
     pars = dict(
         # All values based roughly on https://academic.oup.com/jnci/article/112/10/1030/5753954 or assumptions
         hpv16 = dict(
             hpv16  = 1.0, # Default for own-immunity
-            hpv18 = high_imm,
-            hpv31  = high_imm,
-            hpv33 = high_imm,
-            hpv35 = high_imm,
-            hpv45 = high_imm,
-            hpv51 = med_imm,
-            hpv52 = med_imm,
-            hpv56 = med_imm,
-            hpv58 = med_imm,
-            hpv6 = med_imm,
-            hpv11 = med_imm,
+            hpv18 = cross_imm_high,
+            hpv31  = cross_imm_high,
+            hpv33 = cross_imm_high,
+            hpv35 = cross_imm_high,
+            hpv45 = cross_imm_high,
+            hpv51 = cross_imm_med,
+            hpv52 = cross_imm_med,
+            hpv56 = cross_imm_med,
+            hpv58 = cross_imm_med,
+            hpv6 = cross_imm_med,
+            hpv11 = cross_imm_med,
             hrhpv = 0.1,
-            lrhpv = med_imm
+            lrhpv = cross_imm_med
         ),
 
         hpv18 = dict(
-            hpv16=high_imm,
+            hpv16=cross_imm_high,
             hpv18=1.0,  # Default for own-immunity
-            hpv31=high_imm,
-            hpv33=high_imm,
-            hpv35=high_imm,
-            hpv45=high_imm,
-            hpv51=med_imm,
-            hpv52=med_imm,
-            hpv56=med_imm,
-            hpv58=med_imm,
-            hpv6=med_imm,
-            hpv11=med_imm,
+            hpv31=cross_imm_high,
+            hpv33=cross_imm_high,
+            hpv35=cross_imm_high,
+            hpv45=cross_imm_high,
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
             hrhpv = 0.1,
-            lrhpv = med_imm
+            lrhpv = cross_imm_med
         ),
 
         hpv31=dict(
-            hpv16=high_imm,
-            hpv18=high_imm,
+            hpv16=cross_imm_high,
+            hpv18=cross_imm_high,
             hpv31=1.0,  # Default for own-immunity
-            hpv33=high_imm,
-            hpv35=high_imm,
-            hpv45=high_imm,
-            hpv51=med_imm,
-            hpv52=med_imm,
-            hpv56=med_imm,
-            hpv58=med_imm,
-            hpv6=med_imm,
-            hpv11=med_imm,
-            hrhpv=high_imm,
-            lrhpv=med_imm
+            hpv33=cross_imm_high,
+            hpv35=cross_imm_high,
+            hpv45=cross_imm_high,
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_high,
+            lrhpv=cross_imm_med
         ),
 
         hpv33=dict(
-            hpv16=high_imm,
-            hpv18=high_imm,
-            hpv31=high_imm,
+            hpv16=cross_imm_high,
+            hpv18=cross_imm_high,
+            hpv31=cross_imm_high,
             hpv33=1.0,  # Default for own-immunity
-            hpv35=high_imm,
-            hpv45=high_imm,
-            hpv51=med_imm,
-            hpv52=med_imm,
-            hpv56=med_imm,
-            hpv58=med_imm,
-            hpv6=med_imm,
-            hpv11=med_imm,
-            hrhpv=high_imm,
-            lrhpv=med_imm
+            hpv35=cross_imm_high,
+            hpv45=cross_imm_high,
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_high,
+            lrhpv=cross_imm_med
         ),
 
         hpv35=dict(
-            hpv16=high_imm,
-            hpv18=high_imm,
-            hpv31=high_imm,
-            hpv33=high_imm,
+            hpv16=cross_imm_high,
+            hpv18=cross_imm_high,
+            hpv31=cross_imm_high,
+            hpv33=cross_imm_high,
             hpv35=1.0,  # Default for own-immunity
-            hpv45=high_imm,
-            hpv51=med_imm,
-            hpv52=med_imm,
-            hpv56=med_imm,
-            hpv58=med_imm,
-            hpv6=med_imm,
-            hpv11=med_imm,
-            hrhpv=high_imm,
-            lrhpv=med_imm
+            hpv45=cross_imm_high,
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_high,
+            lrhpv=cross_imm_med
         ),
 
         hpv45=dict(
-            hpv16=high_imm,
-            hpv18=high_imm,
-            hpv31=high_imm,
-            hpv33=high_imm,
-            hpv35=high_imm,
+            hpv16=cross_imm_high,
+            hpv18=cross_imm_high,
+            hpv31=cross_imm_high,
+            hpv33=cross_imm_high,
+            hpv35=cross_imm_high,
             hpv45=1.0,  # Default for own-immunity
-            hpv51=med_imm,
-            hpv52=med_imm,
-            hpv56=med_imm,
-            hpv58=med_imm,
-            hpv6=med_imm,
-            hpv11=med_imm,
-            hrhpv=high_imm,
-            lrhpv=med_imm
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_high,
+            lrhpv=cross_imm_med
         ),
 
         hpv51=dict(
-            hpv16=med_imm,
-            hpv18=med_imm,
-            hpv31=med_imm,
-            hpv33=med_imm,
-            hpv35=med_imm,
-            hpv45=med_imm,
+            hpv16=cross_imm_med,
+            hpv18=cross_imm_med,
+            hpv31=cross_imm_med,
+            hpv33=cross_imm_med,
+            hpv35=cross_imm_med,
+            hpv45=cross_imm_med,
             hpv51=1.0,  # Default for own-immunity
-            hpv52=med_imm,
-            hpv56=med_imm,
-            hpv58=med_imm,
-            hpv6=med_imm,
-            hpv11=med_imm,
-            hrhpv=high_imm,
-            lrhpv=med_imm
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_high,
+            lrhpv=cross_imm_med
         ),
 
         hpv52=dict(
-            hpv16=med_imm,
-            hpv18=med_imm,
-            hpv31=med_imm,
-            hpv33=med_imm,
-            hpv35=med_imm,
-            hpv45=med_imm,
-            hpv51=med_imm,
+            hpv16=cross_imm_med,
+            hpv18=cross_imm_med,
+            hpv31=cross_imm_med,
+            hpv33=cross_imm_med,
+            hpv35=cross_imm_med,
+            hpv45=cross_imm_med,
+            hpv51=cross_imm_med,
             hpv52=1.0,  # Default for own-immunity
-            hpv56=med_imm,
-            hpv58=med_imm,
-            hpv6=med_imm,
-            hpv11=med_imm,
-            hrhpv=high_imm,
-            lrhpv=med_imm
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_high,
+            lrhpv=cross_imm_med
         ),
 
         hpv56=dict(
-            hpv16=med_imm,
-            hpv18=med_imm,
-            hpv31=med_imm,
-            hpv33=med_imm,
-            hpv35=med_imm,
-            hpv45=med_imm,
-            hpv51=med_imm,
-            hpv52=med_imm,
+            hpv16=cross_imm_med,
+            hpv18=cross_imm_med,
+            hpv31=cross_imm_med,
+            hpv33=cross_imm_med,
+            hpv35=cross_imm_med,
+            hpv45=cross_imm_med,
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
             hpv56=1.0,  # Default for own-immunity
-            hpv58=med_imm,
-            hpv6=med_imm,
-            hpv11=med_imm,
-            hrhpv=high_imm,
-            lrhpv=med_imm
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_high,
+            lrhpv=cross_imm_med
         ),
 
         hpv58=dict(
-            hpv16=med_imm,
-            hpv18=med_imm,
-            hpv31=med_imm,
-            hpv33=med_imm,
-            hpv35=med_imm,
-            hpv45=med_imm,
-            hpv51=med_imm,
-            hpv52=med_imm,
-            hpv56=med_imm,
+            hpv16=cross_imm_med,
+            hpv18=cross_imm_med,
+            hpv31=cross_imm_med,
+            hpv33=cross_imm_med,
+            hpv35=cross_imm_med,
+            hpv45=cross_imm_med,
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
             hpv58=1.0,  # Default for own-immunity
-            hpv6=med_imm,
-            hpv11=med_imm,
-            hrhpv=high_imm,
-            lrhpv=med_imm
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_high,
+            lrhpv=cross_imm_med
         ),
 
         hpv6=dict(
-            hpv16=med_imm,
-            hpv18=med_imm,
-            hpv31=med_imm,
-            hpv33=med_imm,
-            hpv35=med_imm,
-            hpv45=med_imm,
-            hpv51=med_imm,
-            hpv52=med_imm,
-            hpv56=med_imm,
-            hpv58=med_imm,
+            hpv16=cross_imm_med,
+            hpv18=cross_imm_med,
+            hpv31=cross_imm_med,
+            hpv33=cross_imm_med,
+            hpv35=cross_imm_med,
+            hpv45=cross_imm_med,
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
             hpv6=1.0,  # Default for own-immunity
-            hpv11=med_imm,
-            hrhpv=med_imm,
-            lrhpv=high_imm
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_med,
+            lrhpv=cross_imm_high
         ),
 
         hpv11=dict(
-            hpv16=med_imm,
-            hpv18=med_imm,
-            hpv31=med_imm,
-            hpv33=med_imm,
-            hpv35=med_imm,
-            hpv45=med_imm,
-            hpv51=med_imm,
-            hpv52=med_imm,
-            hpv56=med_imm,
-            hpv58=med_imm,
-            hpv6=med_imm,
+            hpv16=cross_imm_med,
+            hpv18=cross_imm_med,
+            hpv31=cross_imm_med,
+            hpv33=cross_imm_med,
+            hpv35=cross_imm_med,
+            hpv45=cross_imm_med,
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
             hpv11=1.0,  # Default for own-immunity
-            hrhpv=med_imm,
-            lrhpv=high_imm
+            hrhpv=cross_imm_med,
+            lrhpv=cross_imm_high
         ),
         hrhpv=dict(
             hpv16=0.1,
             hpv18=0.1,
-            hpv31=med_imm,
-            hpv33=med_imm,
-            hpv35=med_imm,
-            hpv45=med_imm,
-            hpv51=med_imm,
-            hpv52=med_imm,
-            hpv56=med_imm,
-            hpv58=med_imm,
-            hpv6=med_imm,
-            hpv11=med_imm,
-            hrhpv=med_imm,
-            lrhpv=med_imm
+            hpv31=cross_imm_med,
+            hpv33=cross_imm_med,
+            hpv35=cross_imm_med,
+            hpv45=cross_imm_med,
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_med,
+            lrhpv=cross_imm_med
         ),
 
         lrhpv=dict(
-            hpv16=med_imm,
-            hpv18=med_imm,
-            hpv31=med_imm,
-            hpv33=med_imm,
-            hpv35=med_imm,
-            hpv45=med_imm,
-            hpv51=med_imm,
-            hpv52=med_imm,
-            hpv56=med_imm,
-            hpv58=med_imm,
-            hpv6=med_imm,
-            hpv11=med_imm,
-            hrhpv=med_imm,
+            hpv16=cross_imm_med,
+            hpv18=cross_imm_med,
+            hpv31=cross_imm_med,
+            hpv33=cross_imm_med,
+            hpv35=cross_imm_med,
+            hpv45=cross_imm_med,
+            hpv51=cross_imm_med,
+            hpv52=cross_imm_med,
+            hpv56=cross_imm_med,
+            hpv58=cross_imm_med,
+            hpv6=cross_imm_med,
+            hpv11=cross_imm_med,
+            hrhpv=cross_imm_med,
             lrhpv=1.0# Default for own-immunity
         ),
     )
